#!/bin/sh
#
# Copyright (c) 2000-2005 Easysoft Ltd. All rights reserved.
#
# This script gathers information about the Easysoft installation,
# ODBC configuration and system information useful when making a 
# support call.
#
# $Id: essupportinfo.sh 24 2005-02-11 09:08:42Z martin $
#
XDIR=`pwd`
DEFAULTOUTFILE="$XDIR/esinfo.txt"
SEPARATOR="----------------------------------------"
#
# Which echo?
#
if [ -x /bin/echo ];then
  ECHO="/bin/echo"
else
  if [ -x /usr/bin/echo ];then
    ECHO="/usr/bin/echo"
  else
    cat <<EOF
Cannot find the echo command
EOF
  exit 1
  fi
fi
#
# echo interprets backslash chrs by default? POSIX says no.
#
test=`$ECHO "fred\c"`
if [ "$test" = "fred\c" ];then
  ECHO="$ECHO -e "
  test=`$ECHO "fred\c"`
  if [ "$test" != "fred" ];then
    cat <<EOF
echo command ($ECHO) does not interpret backslash characters.
You may see backslash c's when asked questions during this install.
You can safely ignore this.
EOF
  fi
fi
#
#
# Need to do tr here as we need to decide what to use for upper->lower
if ( $ECHO "TeSt" | tr '[A-Z]' '[a-z]' 1>/dev/null 2>/dev/null )
then
  lowctest=`$ECHO "TeSt" | tr '[A-Z]' '[a-z]'`
  if [ "$lowctest" != "test" ];then
    $ECHO
    $ECHO "Do not know how to use tr command to convert uppercase to lowercase"
  else
    LOWERCASE="tr '[A-Z]' '[a-z]'"
  fi
fi
if [ "$LOWERCASE" = "" ];then
  lowctest=`$ECHO "TeSt" | dd conv=lcase`
  if [ "$lowctest" != "test" ];then
    $ECHO "Do not know how to use dd command to convert uppercase to lowercase"
  else 
    LOWERCASE="dd conv=lcase"
  fi
fi
if [ "$LOWERCASE" = "" ];then
  lowctest=`$ECHO "TeSt" | sed 'y/TES/tes/'`
  if [ "$lowctest" != "test" ];then
    $ECHO "Do not know how to use sed command to convert uppercase to lowercase"
    $ECHO "Cannot continue without a working tr, dd or sed command"
    exit 1
  else
    LOWERCASE="sed 'y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/'"
  fi
fi
#
#
#
PLATFORM=`uname -s`
platform=`uname -s | $LOWERCASE`
#
#
#
TESTLINK="-L"
if [ "$platform" = "sunos" ];then
  TESTLINK="-h"
fi
if [ "$platform" = "freebsd" ];then
  TESTLINK="-h"
fi
if [ "$platform" = "sinix-n" ];then
  TESTLINK="-h"
fi
#
#
#
cat <<EOF

Easysoft Bug Report Information Collector
=========================================

This program collects information about your machine and installed
software which should prove useful when reporting bugs or problems to
Easysoft support or Easysoft product news groups.

All information is written to a plain text file so you may view it
before mailing. There is no intention to extract sensitive information
but you should check the generated text output file before sending
(in particular, your DSNs are listed and these may contain machine IP
addresses and passwords).

If possible, run this script in the environment you are are having problems
i.e. if running make test for Perl DBD::ODBC run the script in the
session you are running make test in.

Please send the output text file and any other files relevant to your
support request to support@easysoft.com.

EOF
#
# Name of output file?
#
$ECHO "filename for output ($DEFAULTOUTFILE) : \c"
read answer
if [ "$answer" = "" ];then
  answer="$DEFAULTOUTFILE"
fi
OUTFILE="$answer"
#
#
#
> $OUTFILE
$ECHO "Easysoft Support Information" >> $OUTFILE
$ECHO "Generated on `date`" >> $OUTFILE
#
# Who are we?
#
$ECHO "Script run by: `id`" >> $OUTFILE
uid=`id | awk '{print $1}' | awk -F= '{print $2}' | awk -F\( '{print $1}'`
if [ "$uid" != "0" ];then
  cat <<EOF

You are not running this script as the root user. That is OK but some
information gathered by this script will not be complete (e.g. IPC
facilities in use).

EOF
fi
$ECHO "Press the return key to continue"
read press
#
# Hide sensitive info in ODBC ini files?
#
if [ -r ./ini_filter.awk ];then
  cat <<EOF
This script will add the contents of your ODBC ini files into the output
file. Your odbc.ini files may contain passwords. This script can automatically
filter out all attributes that may be a password. It looks for LogonAuth,
TargetAuth, Password and Default_UID (ignoring case).
You should still check the output file yourself.

EOF
  answer="hoho"
  while [ "$answer" != "y" -a "$answer" != "n" ]
  do
    $ECHO "Filter passwords out? (y/n [y]): \c"
    read answer
    if [ "$answer" = "" ];then
      answer="y"
    fi
  done
  FILTERPASSWORDS="$answer"
else
  cat <<EOF 
**WARNING**
Unable to offer to filter sensitive information from your ODBC ini files
because the ini_filter.awk script is missing. You might be running this
script in a different location to the ini_filter.awk script. You can download
the latest filter script from ftp://ftp.easysoft.com/utils.

EOF
  $ECHO "Press the return key to continue"
  read press
  FILTERPASSWORDS="n"
fi
#
#
#
$ECHO $SEPARATOR >> $OUTFILE
$ECHO "Running uname"
$ECHO "uname -a :\n `uname -a`" >> $OUTFILE
#
#
#
$ECHO $SEPARATOR >> $OUTFILE
$ECHO "Examining /usr/local/easysoft to see if it is a symbolic link"
if [ $TESTLINK /usr/local/easysoft ]; then
  $ECHO "test $TESTLINK /usr/local/easysoft (symbolic link)" >> $OUTFILE
else
  $ECHO "test $TESTLINK /usr/local/easysoft (NOT symbolic link)" >> $OUTFILE
fi
$ECHO "ls -la /usr/local/easysoft/:\n `ls -la /usr/local/easysoft/`" >> $OUTFILE
#
ls /usr/local/easysoft 1> /dev/null 2> /dev/null
if [ $? -ne 0 ];then
  EASYSOFTDIR="no"
else
  EASYSOFTDIR="yes"
fi
#
# Licenses
#
$ECHO $SEPARATOR >> $OUTFILE
$ECHO "Examining licenses dir"
$ECHO "ls -la /usr/local/easysoft/license: \n`ls -la /usr/local/easysoft/license`" >> $OUTFILE
ls /usr/local/easysoft/license/licenses 1> /dev/null 2> /dev/null 
if [ $? -ne 0 ];then
  LICENSEFILE=""
  $ECHO "No license file found!" >> $OUTFILE
else
  LICENSEFILE="/usr/local/easysoft/license/licenses"
fi
if [ "$LICENSEFILE" != "" ];then
  $ECHO "Examining licenses"
  $ECHO $SEPARATOR >> $OUTFILE
  $ECHO "License File:\n`cat $LICENSEFILE`" >> $OUTFILE
  $ECHO $SEPARATOR >> $OUTFILE
  if [ -x /usr/local/easysoft/license/licclient ];then
    #
    # save the values of env vars we are going to change and put them back
    # afterwards or they will appear with our changes later in this script.
    #
    ld_library_path="$LD_LIBRARY_PATH"
    LD_LIBRARY_PATH="$LD_LIBRARY_PATH:/usr/local/easysoft/lib"
    dyld_library_path="DYLD_LIBRARY_PATH"
    DYLD_LIBRARY_PATH="$DYLD_LIBRARY_PATH:/usr/local/easysoft/lib"
    shlib_path="$SHLIB_PATH"
    SHLIB_PATH="$SHLIB_PATH:/usr/local/easysoft/lib"
    libpath="$LIBPATH"
    LIBPATH="$LIBPATH:/usr/local/easysoft/lib"
    export LD_LIBRARY_PATH
    export DYLD_LIBRARY_PATH
    export SHLIB_PATH
    export LIBPATH
    $ECHO "Running licclient to show licenses" | tee -a $OUTFILE
    /usr/local/easysoft/license/licclient view >> $OUTFILE
    $ECHO "Running licclient to show products" | tee -a $OUTFILE
    /usr/local/easysoft/license/licclient products >> $OUTFILE
    $ECHO "Running licclient to show semaphore created" | tee -a $OUTFILE
    /usr/local/easysoft/license/licclient semcreated
    $ECHO "licclient semcreated = $?" >> $OUTFILE
    /usr/local/easysoft/license/licclient seminfo 2>&1 >> $OUTFILE  
    LD_LIBRARY_PATH="$ld_library_path"
    export LD_LIBRARY_PATH
    DYLD_LIBRARY_PATH="$dyld_library_path"
    export DYLD_LIBRARY_PATH
    SHLIB_PATH="$shlib_path"
    export SHLIB_PATH
    LIBPATH="$libpath"
    export LIBPATH
  fi
fi
#
# Semaphores
#
$ECHO "Examining system IPC"
$ECHO $SEPARATOR >> $OUTFILE
$ECHO "ipcs -a:\n `ipcs -sa`" >> $OUTFILE
$ECHO
#
# Environment variables
#
$ECHO $SEPARATOR >> $OUTFILE
$ECHO "Outputting relevant environment variables" | tee -a $OUTFILE
$ECHO "LD_LIBRARY_PATH: $LD_LIBRARY_PATH" >> $OUTFILE
$ECHO "DYLD_LIBRARY_PATH: $DYLD_LIBRARY_PATH" >> $OUTFILE
$ECHO "LD_RUN_PATH: $LD_RUN_PATH" >> $OUTFILE
$ECHO "SHLIB_PATH: $SHLIB_PATH" >> $OUTFILE
$ECHO "LIBPATH: $LIBPATH" >> $OUTFILE
$ECHO "ODBCINI: $ODBCINI" >> $OUTFILE
$ECHO "ODBCSEARCH: $ODBCSEARCH" >> $OUTFILE
$ECHO "ORACLE_HOME: $ORACLE_HOME" >> $OUTFILE
$ECHO "LANG: $LANG" >> $OUTFILE
#
#  ODBC ini files
#
$ECHO $SEPARATOR >> $OUTFILE
$ECHO "Examining ODBC ini files" | tee -a $OUTFILE
inis="/etc/odbcinst.ini /usr/local/etc/odbcinst.ini "
inis="$inis /etc/odbc.ini /usr/local/etc/odbc.ini "
if [ "$HOME" ];then
  home="$HOME"
else
  home=`grep martin /etc/passwd | awk -F: '{print $6}'`
fi
if [ -d "$home" ];then
  inis="$inis $home/odbc.ini $home/.odbc.ini"
fi
for ini in $inis
do
  if [ -r $ini ];then
    $ECHO "Examining $ini"
    $ECHO $SEPARATOR >> $OUTFILE

    if [ "$FILTERPASSWORDS" = "y" ];then
      $ECHO "cat $ini:\n `awk -F= -f ./ini_filter.awk < $ini`" >> $OUTFILE
    else
      $ECHO "cat $ini:\n `cat $ini`" >> $OUTFILE
    fi
  fi
done
#
#
#
$ECHO $SEPARATOR >> $OUTFILE
$ECHO "unixODBC configuration" | tee -a $OUTFILE
PATHSTOSEARCH="/usr/local/easysoft/unixODBC /usr/local /usr/local/unixODBC /opt/unixODBC /usr"
FOUND=""
for dir in $PATHSTOSEARCH
do
  if [ -x "$dir/bin/odbcinst" ];then
      $ECHO "Found odbcinst at $dir/bin" >> $OUTFILE
      FOUND="$FOUND $dir"
  fi
done
if [ "$FOUND" != "" ];then
  for oi in $FOUND
  do
    $ECHO "  odbcinst in $oi :" >> $OUTFILE
    $oi/bin/odbcinst -j >> $OUTFILE
  done
fi
#
# Perl
#
answer="hoho"
perl -e 'print '';' 2>/dev/null 1>/dev/null
if [ $? -ne 0 ]; then
  $ECHO "Failed to find perl"
  perldef="n"
else
  perldef="y"
fi
while [ \( "$answer" != "y" \) -a \( "$answer" != "n" \) ]
do
  $ECHO "Are you using Perl with this product (y/n) [$perldef]: \c"
  read answer
  if [ "$answer" = "" ];then
    answer="$perldef"
  fi
done
if [ "$answer" = "y" ];then
  $ECHO "Examining Perl"
  $ECHO $SEPARATOR >> $OUTFILE
  $ECHO "perl -v:" >> $OUTFILE
  perl -v >> $OUTFILE
  $ECHO "perl -V:" >> $OUTFILE
  perl -V >> $OUTFILE
  TESTPERL="/tmp/estestperl.pl"
  > $TESTPERL
  $ECHO "use Config;" >> $TESTPERL
  $ECHO "use Config qw(config_sh);" >> $TESTPERL
  $ECHO "print config_sh();" >> $TESTPERL
  $ECHO "perl $TESTPERL:\n`perl $TESTPERL`" >> $OUTFILE
  $ECHO "DBI_DSN=$DBI_DSN" >> $OUTFILE
  $ECHO "DBI_USER=$DBI_USER" >> $OUTFILE
  $ECHO "DBI_PASS=$DBI_PASS" >> $OUTFILE
fi
#
# Apache/PHP
#
answer="hoho"
while [ \( "$answer" != "y" \) -a \( "$answer" != "n" \) ]
do
  $ECHO "Are you using Apache/PHP with this product? (y/n) [y] : \c"
  read answer
  if [ "$answer" = "" ];then
    answer="y"
  fi
done
if [ "$answer" = "y" ];then
  WEDDIR=""
  while [ "$WEBDIR" = "" ]
  do
    $ECHO "Where have you built/installed Apache/PHP? (q=cancel): \c"
    read WEBDIR
    if [ "$WEBDIR" != "q" ];then
      if [ ! -d "$WEBDIR" ];then
        $ECHO "$WEBDIR does not appear to exist"
        WEBDIR=""
      else
        if [ ! -d "$WEBDIR/bin" ]; then
          $ECHO "$WEBDIR/bin does not appear to exist"
          WEBDIR=""
        fi
      fi
    fi
  done
  if [ "$WEBDIR" != "q" ];then
    $ECHO $SEPARATOR >> $OUTFILE
    if [ -x "$WEBDIR/bin/httpd" ];then
      HTTPD="$WEBDIR/bin/httpd"
    elif [ -x "$WEBDIR/sbin/httpd" ];then
      HTTPD="$WEBDIR/sbin/httpd"
    else
      HTTPD=""
    fi
    if [ "$HTTPD" != "" ];then 
      $ECHO "Running $HTTPD -v" | tee -a $OUTFILE
      $ECHO "$HTTPD -v:\n`$HTTPD -v`" >> $OUTFILE
      $ECHO "Running $HTTPD -V" | tee -a $OUTFILE
      $ECHO "$HTTPD -V:\n`$HTTPD -V`" >> $OUTFILE
      $ECHO "Running $HTTPD -l" | tee -a $OUTFILE
      $ECHO "$HTTPD -l:\n`$HTTPD -l`" >> $OUTFILE
      $ECHO "Running $HTTPD -t" | tee -a $OUTFILE
      $HTTPD -t >> $OUTFILE 2>&1
    fi
  fi
fi
#
# Shared objects
#
cwd=`pwd`
cd /usr/local/easysoft/lib
$ECHO "Examining Shared object versions and build dates"
$ECHO $SEPARATOR >> $OUTFILE
for i in libes* libextra.* libsupport.*
do
  if [ -r "$i" ];then
    $ECHO "    $i"
    $ECHO "sum $i: `sum $i`" >> $OUTFILE
    $ECHO "Ident for $i" >> $OUTFILE
    strings $i | grep Built >> $OUTFILE 
    strings $i | grep Revision >> $OUTFILE 
  else
    $ECHO "Could not find $i" | tee -a $OUTFILE
  fi
done
cd "$cwd"
#
# OOB
#
cd /usr/local/easysoft
for i in oob/client/libesoobclient.* oob/server/esoobserver 
do
  if [ -r "$i" ];then
    $ECHO $SEPARATOR >> $OUTFILE
    $ECHO "    $i"
    $ECHO "sum $i: `sum $i`" >> $OUTFILE
    $ECHO "Ident for $i" >> $OUTFILE
    strings $i | grep Built >> $OUTFILE 
    strings $i | grep Revision >> $OUTFILE 
  else
    $ECHO "Could not find $i" | tee -a $OUTFILE 
  fi
done
cd "$cwd"
#
# esoobserver dir and esoobserver.ini file
#
$ECHO $SEPARATOR >> $OUTFILE
if [ ! -d /usr/local/easysoft/oob/server ];then
  $ECHO "/usr/local/easysoft/oob/server does not exist" >> $OUTFILE
else
  ls -la /usr/local/easysoft/oob/server >> $OUTFILE
fi
if [ -r /usr/local/easysoft/oob/server/esoobserver.ini ];then
  $ECHO "Saving contents of esoobserver.ini file" | tee -a $OUTFILE
  cat /usr/local/easysoft/oob/server/esoobserver.ini >> $OUTFILE
fi
#
# JOB
#
cd /usr/local/easysoft
for i in job/server/esjobserver
do
  if [ -r "$i" ];then
    $ECHO $SEPARATOR >> $OUTFILE
    $ECHO "    $i"
    $ECHO "sum $i: `sum $i`" >> $OUTFILE
    $ECHO "Ident for $i" >> $OUTFILE
    strings $i | grep Built >> $OUTFILE 
    strings $i | grep Revision >> $OUTFILE 
  else
    $ECHO "Could not find $i" | tee -a $OUTFILE 
  fi
done
cd "$cwd"
#
# esjobserver dir and esoobserver.ini file
#
$ECHO $SEPARATOR >> $OUTFILE
if [ ! -d /usr/local/easysoft/job/server ];then
  $ECHO "/usr/local/easysoft/job/server does not exist" >> $OUTFILE
else
  ls -la /usr/local/easysoft/job/server >> $OUTFILE
fi
if [ -r /usr/local/easysoft/job/server/esjobserver.ini ];then
  $ECHO "Saving contents of esjobserver.ini file" | tee -a $OUTFILE
  cat /usr/local/easysoft/job/server/esjobserver.ini >> $OUTFILE
fi
#
# Services and inetd
#
$ECHO "Examining services" | tee -a $OUTFILE
$ECHO $SEPARATOR >> $OUTFILE
if [ -r /etc/services ];then
  $ECHO "/etc/services exists" >> $OUTFILE
  $ECHO "grep -i easysoft:\n`grep -i easysoft /etc/services`" >> $OUTFILE
  $ECHO "grep -i esoob:\n`grep -i esoob /etc/services`" >> $OUTFILE
fi
if [ -r /etc/inetd.conf ];then
  $ECHO "/etc/inetd.conf exists" >> $OUTFILE
  $ECHO "grep -i easysoft:\n`grep -i easysoft /etc/inetd.conf`" >> $OUTFILE
  $ECHO "grep -i esoob:\n`grep -i esoob /etc/inetd.conf`" >> $OUTFILE
fi
#
# Version of products
#
$ECHO "Looking for Easysoft installation information file"
for file in /usr/local/easysoft/*_install.info
do
  $ECHO $SEPARATOR >> $OUTFILE
  $ECHO "$file:" >> $OUTFILE
  cat "$file" >> $OUTFILE
done
#
# Oracle
#
if [ "$ORACLE_HOME" != "" ];then
  $ECHO "Examining Oracle installation"
  if [ -r "$ORACLE_HOME/network/admin/tnsnames.ora" ];then
      $ECHO $SEPARATOR >> $OUTFILE
      $ECHO "tnsnames.ora" >> $OUTFILE
      cat "$ORACLE_HOME/network/admin/tnsnames.ora" >> $OUTFILE
  fi
  for file in "$ORACLE_HOME/lib/libclntsh*"
  do
    ls -la $file >> $OUTFILE
  done
fi
#
# Have any log files been generated
#
LOGS=""
clientlogs=`ls /tmp/esoobclient.log_* 2>/dev/null`
if [ "$clientlogs" != "" ];then
  $ECHO "Found some OOB Client log files in /tmp"
  $ECHO $clientlogs
  LOGS="client"
fi
serverlogs=`ls /tmp/esoobserver.log_* 2>/dev/null`
if [ "$serverlogs" != "" ];then
  $ECHO "Found some OOB Server log files in /tmp"
  $ECHO $serverlogs
  LOGS="$LOGS, server"
fi
serverslogs=`ls /tmp/esoobstart_*.log 2>/dev/null`
if [ "$serverslogs" != "" ];then
  $ECHO "Found some OOB Server startup log files in /tmp"
  $ECHO $serverslogs
  LOGS="$LOGS, $serverslogs"
fi
diaglogs=`ls /tmp/odbc_bridge*_diags.txt 2>/dev/null`
if [ "$diaglogs" != "" ];then
  $ECHO "Found some client/server ODBC diagnostic logs"
  $ECHO $diaglogs
  LOGS="$LOGS, $diaglogs"
fi
exceptlogs=`ls /tmp/esoob.except* 2>/dev/null`
if [ "$exceptlogs" != "" ];then
  $ECHO "Found some server exception files"
  $ECHO $exceptlogs
  LOGS="$LOGS, $exceptlogs"
fi
if [ "$LOGS" != "" ];then
  cat <<EOF

OOB log files were found. If these are relevant to your problem please
attach them to any email you send to us with your support call.

EOF
  $ECHO "Press the return key to continue"
  read press
fi
#
#  Platform specific tests
#
if [ "$platform" = "linux" ];then
  $ECHO "Performing Linux specific operations"
  $ECHO $SEPARATOR >> $OUTFILE
  #
  # Distributions
  #
  if [ -r /etc/redhat-release ];then
    $ECHO "/etc/redhat-release: `cat /etc/redhat-release`" >> $OUTFILE
  fi
  ls -la /usr/lib/setup/slack* 2>/dev/null >> $OUTFILE
  $ECHO $SEPARATOR >> $OUTFILE
  $ECHO "Examining /etc/ld.so.conf"
  $ECHO "/etc/ld.so.conf:\n `cat /etc/ld.so.conf`" >> $OUTFILE
  #
  #
  #
  $ECHO "Checking linkage of demo program"
  $ECHO $SEPARATOR >> $OUTFILE
  if [ -x /usr/local/easysoft/oob/examples/demo ];then
    $ECHO "ldd /usr/local/easysoft/oob/examples/demo:\n" >> $OUTFILE
    ldd /usr/local/easysoft/oob/examples/demo >> $OUTFILE
  fi
  #
  #
  #
  $ECHO "Examining /lib"
  $ECHO $SEPARATOR >> $OUTFILE
  $ECHO "ls -la /lib/libc*:\n `ls -la /lib/libc*`" >> $OUTFILE
  $ECHO "Examining /usr/lib"
  $ECHO $SEPARATOR >> $OUTFILE
  $ECHO "ls -la /usr/lib/libc*:\n `ls -la /usr/lib/libc*`" >> $OUTFILE
  #
  #
  #
  TESTPROGRAM="/tmp/estestprogram.c"
  TESTPROGRAMEXE="/tmp/estestprogram"
  $ECHO "Creating $TESTPROGRAM"
  > $TESTPROGRAM
  $ECHO "#include <stdio.h>" >> $TESTPROGRAM
  $ECHO "#include <math.h>" >> $TESTPROGRAM
  $ECHO "main()" >> $TESTPROGRAM
  $ECHO "{" >> $TESTPROGRAM
  $ECHO "printf(\"hello%1.0f\\\n\",ceil(3.14));" >> $TESTPROGRAM
  $ECHO "}" >> $TESTPROGRAM
  $ECHO "Test program is:\n`cat $TESTPROGRAM`"
  $ECHO "Ok to compile, link and run it? (y/n) [y] : \c"
  read answer
  if [ "$answer" = "" ];then
    answer="y"
  fi
  if [ "$answer" = "y" ];then
    cwd=`pwd`
    cd /tmp
    $ECHO "Running cc -o $TESTPROGRAMEXE $TESTPROGRAM"
    cc -o $TESTPROGRAMEXE $TESTPROGRAM -lm
    $ECHO "Running test program:" >> $OUTFILE
    $TESTPROGRAMEXE >> $OUTFILE
    $ECHO "ldd $TESTPROGRAMEXE" >> $OUTFILE
    ldd $TESTPROGRAMEXE >> $OUTFILE
    cd "$cwd"
  fi
elif [ \( "$platform" = "sco_sv" \) -o \( "$platform" = "unixware" \) ];then
  $ECHO "Performing $platform specific operations"
  $ECHO $SEPARATOR >> $OUTFILE
  $ECHO "Examining /etc/conf/cf.d/stune"
  if [ -r /etc/conf/cf.d/stune ];then
    $ECHO "/etc/conf/cf.d:\n `cat /etc/conf/cf.d/stune`" >> $OUTFILE  
  fi
fi
cat <<EOF

The script generated output is in 
$OUTFILE

Please attach this and any other files pertinent to your problem to
any support requests you make. You can email support requests to
support@easysoft.com or post general issues to the OOB news group at
news://news.easysoft.com/easysoft.public.da2k.odbc-odbc-bridge. Don't
forget to check the FAQ distributed with OOB before asking for
support.

EOF

